package App::lcpan::CmdBundle::debian;

our $DATE = '2021-07-17'; # DATE
our $VERSION = '0.008'; # VERSION

1;
# ABSTRACT: More lcpan subcommands related to Debian

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::CmdBundle::debian - More lcpan subcommands related to Debian

=head1 VERSION

This document describes version 0.008 of App::lcpan::CmdBundle::debian (from Perl distribution App-lcpan-CmdBundle-debian), released on 2021-07-17.

=head1 SYNOPSIS

=head1 DESCRIPTION

This bundle provides the following lcpan subcommands:

=over

=item * L<lcpan debian-dist2deb|App::lcpan::Cmd::debian_dist2deb>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan-CmdBundle-debian>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan-CmdBundle-debian>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan-CmdBundle-debian>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<lcpan>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
